@@ -57,6 +57,8 @@
 #include <sys/mman.h>
 #include <stddef.h>
 #include <netinet/in.h>
+#include <arpa/inet.h>
+
 
 /*
 #include "rpgnet.h"
@@ -80,11 +82,11 @@
 #  define dcgettext(Domain,String,Type) (String)
 #  define bindtextdomain(Domain,Directory) (Domain) 
 #endif /* ENABLE_NLS */
-#ifndef RPG_OK
-#	define RPG_OK		1
+#ifndef LP_OK
+#	define LP_OK		1
 #endif
-#ifndef RPG_NG
-#	define RPG_NG		0
+#ifndef LP_NG
+#	define LP_NG		0
 #endif
 #ifndef FALSE
 #define FALSE 0
@@ -93,61 +95,62 @@
 #define TRUE 1
 #endif
 
-#define LIBNET
-#define LIBNET
-#define LIBNETOREDYOPEN				20001		/*Ǥ˶꤬ͭץ󤵤Ƥ*/	
-#define LIBNETFDAREDYSET			20002		/*ǤˣƣĤоݤȤϿƤ*/
-#define LIBNETCONNECTREQUESTRAWT	10012		/*TCP RAWSERVER ³׵*/
-#define LIBNETCONNECTREQUESTRAWU	10011		/*UNIX SOC RAWSERVER³׵*/
-#define LIBNETRAWRESEVE				10010		/*RAWFDȯ*/
-#define LIBNETCONNECTREQUESTT		10009		/*TCP ³׵*/
-#define LIBNETCONNECTREQUESTU		10008		/*UNIX SOCK ³׵*/
-#define LIBNETFDOPEN				10007		/*ƣĤ򥪡ץ󤷤*/
-#define LIBNETNOTOPENLOG			10006		/*ץ󤵤Ƥʤ*/
-#define LIBNETWTIMEUP				10005		/*׵ᤵ줿٥ȤΤɤ줫˥ʥ뤬ȯ*/
-#define LIBNETDATAPARTIALLOST		10004		/*ʬŪ˥ǡ򼺤ä*/
-#define LIBNETNOIDCONTINU			10003		/*ɣĤϢ³Ƥʤ*/
-#define LIBNETLOSTDATA				10002		/*ǡХåեξ꾮*/
-#define LIBNETOK					10001		/**/
-#define LIBNETNOFD					-10001		/*ƣĤäƤʤ*/
-#define LIBNETNOFDENT				-10002		/*ƣĤΥȥ꤬ʤ*/
-#define LIBNETSENDERR				-10003		/**/
-#define LIBNETHEADSENDERR			-10004		/*إåɤ߹ޤʤä*/
-#define LIBNETMALOCCERR				-10005		/*γݼ*/
-#define LIBNETMAKESOCERR			-10006		/*åȤκ顼*/
-#define LIBNETGETPORTERR			-10007		/*ݡֹμ顼*/
-#define LIBNETSETHOSTNEMEERR		-10008		/*ۥȥ͡Υåȼ*/
-#define LIBNETCONECTERR				-10009		/*ͥȥ顼*/
-#define LIBNETSIGSETERR				-10010		/*ʥΥåȥ顼*/
-#define LIBNETPOLLERR				-10011		/* Error condition */
-#define LIBNETPOLLHUP				-10012		/* Hung up */
-#define LIBNETPOLLNVAL				-10013		/* Invalid request: fd not open */
-#define LIBNETEFAULT				-10015		/*Ȥƻꤷ󤬡ƤӽФץΥɥ쥹֤˴ޤޤƤʤ*/
-#define LIBNETERR					-10014		/*¾Υ顼*/
-#define LIBNETHEADBREAK				-10015		/*إåʬƤ*/
-#define LIBNETREADBREAK				-10016		/*ɤ߹ߤΥʥˤ*/
-#define LIBNETNOREQLEN				-10017		/*׵Ĺޤϥޥʥ*/
-#define LIBNETOTHERSIG				-10018		/* ͽʤʥˤ*/
-#define LIBNETOREDYSOPEN			-10019		/*Ǥ˥Хץ󤷤Ƥ*/
-#define LIBNETLENGTHZERO			-10020		/*Ĺξ*/
-#define LIBNETCONNECTIONERROR		-10021		/*³μ*/
-#define LIBNETCONNECTIONDATAERR		-10022		/*³³ʸǤʤä*/
-#define LIBNETCATCREATFD			-10023		/*ƥ¤ǤʾƣĤ򥪡ץǤʤ*/
-#define LIBNETREADLENLESS			-10024		/*ɤ߹Ĺ*/
-#define LIBNETSOCBINDERR			-10025		/*åȤΥХɥ顼*/
-#define LIBNETLISSTENERR			-10026		/*listen򥽥åȤФȯԼ*/
-#define LIBNET	
-#define LIBNETERROTHER				-10100		/*¾ͽʤ顼*/
-#define LIBNETSHMaredyattach		-20001		/*Ǥ˥ץ󤵤줿ɣ*/
-#define LIBNETSHMNOIDentry			-20002		/*Ǥ˥ץ󤵤줿ɣ*/
-#define LIBNETSHMATTACHERR			-20003		/*ͭꥢå顼*/
-#define LIBNETSHMGETERR				-20004		/*ͭꥲåȥ顼*/
-#define LIBNETSHMIDerror			-20005		/*ͭɣĤϿƤޤ*/
-#define LIBNETSHMMALOCCERR			-20006		/*Υޥå˼Ԥޤ*/
-#define LIBNETSHMNOSHMID			-20007		/*ͭɣĤϿƤޤ*/
-#define LIBNETSHMNOINIT				-20008		/*ͭꥳȥ뤬Ƥʤ*/
-#define LIBNETSHM
-#define LIBNETSHM
+/* ͡οｪλοϥ顼ɽ  */
+#define LIBNET_STAT_
+#define LIBNET_STAT_
+#define LIBNET_STAT_ALREADYOPEN				20001		/*Ǥ˶꤬ͭץ󤵤Ƥ*/	
+#define LIBNET_STAT_FDALREADYSET			20002		/*ǤˣƣĤоݤȤϿƤ*/
+#define LIBNET_STAT_CONNECTREQUESTRAWT	10012		/*TCP RAWSERVER ³׵*/
+#define LIBNET_STAT_CONNECTREQUESTRAWU	10011		/*UNIX SOC RAWSERVER³׵*/
+#define LIBNET_STAT_RAWRESEVE				10010		/*RAWFDȯ*/
+#define LIBNET_STAT_CONNECTREQUESTT		10009		/*TCP ³׵*/
+#define LIBNET_STAT_CONNECTREQUESTU		10008		/*UNIX SOCK ³׵*/
+#define LIBNET_STAT_FDOPEN				10007		/*ƣĤ򥪡ץ󤷤*/
+#define LIBNET_STAT_NOTOPENLOG			10006		/*ץ󤵤Ƥʤ*/
+#define LIBNET_STAT_WTIMEUP				10005		/*׵ᤵ줿٥ȤΤɤ줫˥ʥ뤬ȯ*/ /* :ǻȤƤ롣ʬɤ⡣ */
+#define LIBNET_STAT_DATAPARTIALLOST		10004		/*ʬŪ˥ǡ򼺤ä*/
+#define LIBNET_STAT_NOIDCONTINUE			10003		/*ɣĤϢ³Ƥʤ*/
+#define LIBNET_STAT_LOSTDATA				10002		/*ǡХåեξ꾮*/
+#define LIBNET_STAT_OK					10001		/**/
+#define LIBNET_STAT_NOFD					-10001		/*ƣĤäƤʤ*/
+#define LIBNET_STAT_NOFDENT				-10002		/*ƣĤΥȥ꤬ʤ*/
+#define LIBNET_STAT_SENDERR				-10003		/**/
+#define LIBNET_STAT_HEADSENDERR			-10004		/*إåɤ߹ޤʤä*/
+#define LIBNET_STAT_MALLOCERR				-10005		/*γݼ*/
+#define LIBNET_STAT_MAKESOCKETERR			-10006		/*åȤκ顼*/
+#define LIBNET_STAT_GETPORTERR			-10007		/*ݡֹμ顼*/
+#define LIBNET_STAT_SETHOSTNAMEERR		-10008		/*ۥȥ͡Υåȼ*/
+#define LIBNET_STAT_CONNECTERR				-10009		/*ͥȥ顼*/
+#define LIBNET_STAT_SIGSETERR				-10010		/*ʥΥåȥ顼*/
+#define LIBNET_STAT_POLLERR				-10011		/* poll()ǤΥ顼 */
+#define LIBNET_STAT_POLLHUP				-10012		/* poll()Ǹ */ /* :ǻȤƤ롣ʬɤ⡣ */
+#define LIBNET_STAT_POLLNVAL				-10013		/* poll()ǻꤵƤե뵭һҤץ󤵤Ƥʤ */
+#define LIBNET_STAT_EFAULT				-10015		/*Ȥƻꤷ󤬡ƤӽФץΥɥ쥹֤˴ޤޤƤʤ*/
+#define LIBNET_STAT_ERR					-10014		/*¾Υ顼*/
+#define LIBNET_STAT_HEADRECVERR				-10015		/*إåʬƤ*/
+#define LIBNET_STAT_READBREAK				-10016		/*ɤ߹ߤΥʥˤ*/
+#define LIBNET_STAT_NOREQLEN				-10017		/*׵Ĺޤϥޥʥ*/
+#define LIBNET_STAT_OTHERSIG				-10018		/* ͽʤʥˤ*/
+#define LIBNET_STAT_ALREADYSOPEN			-10019		/*Ǥ˥Хץ󤷤Ƥ*/
+#define LIBNET_STAT_LENGTHZERO			-10020		/*Ĺξ*/
+#define LIBNET_STAT_CONNECTIONERR		-10021		/*³μ*/
+#define LIBNET_STAT_CONNECTIONDATAERR		-10022		/*³³ʸǤʤä*/
+#define LIBNET_STAT_CANTCREATEFD			-10023		/*ƥ¤ǤʾƣĤ򥪡ץǤʤ*/
+#define LIBNET_STAT_READLENLESS			-10024		/*ɤ߹Ĺ*/
+#define LIBNET_STAT_SOCKETBINDERR			-10025		/*åȤΥХɥ顼*/
+#define LIBNET_STAT_LISTENERR			-10026		/*listen򥽥åȤФȯԼ*/
+#define LIBNET_STAT_	
+#define LIBNET_STAT_ERROTHER				-10100		/*¾ͽʤ顼*/
+#define LIBNET_STAT_SHMALREADYATTACH		-20001		/*Ǥ˥ץ󤵤줿ɣ*/
+#define LIBNET_STAT_SHMNOIDENTRY			-20002		/*ɣĤ̤Ͽ*/
+#define LIBNET_STAT_SHMATTACHERR			-20003		/*ͭꥢå顼*/
+#define LIBNET_STAT_SHMGETERR				-20004		/*ͭꥲåȥ顼*/
+#define LIBNET_STAT_SHMIDERR			-20005		/*ͭɣĤϿƤޤ*/
+#define LIBNET_STAT_SHMMALLOCERR			-20006		/*Υޥå˼Ԥޤ*/
+#define LIBNET_STAT_SHMNOSHMID			-20007		/*ͭɣĤϿƤޤ*/
+#define LIBNET_STAT_SHMNOINIT				-20008		/*ͭꥳȥ뤬Ƥʤ*/
+#define LIBNET_STAT_SHM
+#define LIBNET_STAT_SHM
 #define RPGMALLOCERROR				-30001
 
 #define RPGLOGREQ					"RPGLOGREQ_"			/*׵*/
@@ -162,8 +165,8 @@
 #define LIBNETLOGSOCNAME			""
 #define LIBNETTIMEUP				100
 
-#define COMMANDLEN					10
-#define LOGLINEMAX					10000			/*κ饤*/
+#define COMMANDLEN					10				/* ޥʸĹ('\0'ϴޤޤʤ) */
+#define LOGLINEMAX					100000			/*κ饤*/
 #define LOGFILENAME					"Laurier.log"
 #define LOGBUFFSIZE					256
 #define MAXERRNOM					100
@@ -180,31 +183,38 @@
 #ifndef MAXPATHLEN
 #	define MAXPATHLEN				512
 #endif
+
 /**************************************************************************/
 /*Υإåι¤
-ǥѥåȤĤʤäڤ줿ꤷˤб롣
-Υإåκǽ*/
+ǥѥåȤĤʤäڤ줿ꤷˤб롣 */
 
-#define LIBNETPHEADER				"NRPGHEAD"	/*ѥåȥإå*/
-#define LIBNETASSEPT				"LIBNETASSEPT"	 
-#define LIBNETCONNECTREQ			"CONNECTREQ"	/*³׵*/
-#define LIBNETRAWCONNECTREQ			"CNCTRAWREQ"	/*³׵*/
-#define POLLTIMEUP          		"POLLTIMEUP"            /**/
-#define LIBNETRAWDATARECEVE			"RAWDATAREC"
-#define LIBNETWTIMEUP2				"LIBNETIMUP"
-/*		ʸ󤬤뤳,
+/* ̾⡼ɤ³Ωľ塢饤Ȥʸ */
+#define LIBNET_STR_ACCEPT				"LIBNETACCEPT"	 
+
+/* ޥʸ */
+#define LIBNET_CMD_CONNECTREQ			"CONNECTREQ"	/* ³׵(ɸ⡼) */
+#define LIBNET_CMD_RAWCONNECTREQ		"CNCTRAWREQ"	/* ³׵(Raw⡼) */
+#define LIBNET_CMD_POLLTIMEUP          	"POLLTIMEUP"    /* ٥ȥݡ󥰻ڤ */
+#define LIBNET_CMD_RAWDATARECEIVE		"RAWDATAREC"	/* ǡ(Raw⡼) */
+#define LIBNET_CMD_RAWDATARECEVE		LIBNET_CMD_RAWDATARECEIVE
+#define LIBNET_CMD_WTIMEUP				"LIBNETIMUP"
+#define LIBNET_CMD_CLOSEFD				"LIBNCLOSFD"	/* ꤫ */
+#define LIBNET_CMD_RECEIVEERROR			"LIBNETRERR"	/* 顼ȯ */
+
+#define LIBNET_STR_PHEADER				"NRPGHEAD"	/*ѥåȥإå*/
+/*		Υإåκǽ
+		ʸ󤬤뤳,
 		length
 		ID
 		from_pid
 		ǣңУǤΥǡȽǤ롣*/
-
 typedef struct{
-	char head [9];
-	int length;
-	int status;
-	int ID;
-	int from_pid;
-	char command[11];
+	char head [9];						/* ѥåȥإå"NRPGHEAD" */
+	int length;							/* */
+	int status;							/* */
+	int ID;								/* */
+	int from_pid;						/* */
+	char command[ COMMANDLEN + 1 ];		/* ޥʸ */
 }libnet_send_st;
 
 
@@ -220,22 +230,22 @@ typedef struct{
 
 Ȥ
 С¦
-	rpg_serveropen(AF_INET ,   "service name" );	ǥСץ
-	ret = RPG_Poll (command ,  readbuf , 1024, &read_len , 1 , &resfd );
+	LP_serveropen(AF_INET ,   "service name" );	ǥСץ
+	ret = LP_Poll (command ,  readbuf , 1024, &read_len , 1 , &resfd );
 							ǥ٥ȥ롼
 	ΣĤǥॢȻ֤ƤСʤˤʤȴƤ뤷
 	δ֤˼readbuf˥ǡäƤޤ
 
 饤¦
-    serverFD=rpg_tcp_client_open( "server adress" ,  "service name" );
+    serverFD=LP_tcp_client_open( "server adress" ,  "service name" );
 													ǥ饤ȥץ
-	ret = RPG_Poll (command ,  readbuf , 1024, &read_len , 1 , &resfd );
+	ret = LP_Poll (command ,  readbuf , 1024, &read_len , 1 , &resfd );
 							ǥ٥ȥ롼
 	ΣĤǥॢȻ֤ƤСʤˤʤȴƤ뤷
 	δ֤˼readbuf˥ǡäƤޤ
 
 ξ
-	ret=rpg_send(FD, COMMAND , data ,strlen(data));
+	ret=LP_send(FD, COMMAND , data ,strlen(data));
 							Ǥ
 
 ʤˤüʪϤޤ󤬡üʤΤϣãϣͣͣΣĤǤ礦
@@ -261,7 +271,7 @@ typedef struct{
 		ʤ
 */
 
-void	rpg_closefd(int FD);
+void	LP_closefd(int FD);
 
 
 /**************************************************************************/
@@ -280,7 +290,7 @@ void	rpg_closefd(int FD);
 
 */
 
-void rpg_fd_allclose(void);
+void LP_fd_allclose(void);
 
 
 /**************************************************************************/
@@ -292,14 +302,14 @@ void rpg_fd_allclose(void);
 		int data	I	
 */
 
-void  rpg_childdeth(int data);
+void  LP_childdeth(int data);
 
 
 /**************************************************************************/
 /*	
 		λ*/
 
-void rpg_endproc(int data);
+void LP_endproc(int data);
 
 /**************************************************************************/
 /*	
@@ -318,7 +328,7 @@ void rpg_endproc(int data);
  
  */
 
-int rpg_addRawPollFD(int FD);
+int LP_addRawPollFD(int FD);
 
 
 /**************************************************************************/
@@ -345,7 +355,7 @@ int rpg_addRawPollFD(int FD);
 			顼ξ֤ͤ
 */
 
-int rpg_serveropen (int type ,	char * service_name );
+int LP_serveropen (int type ,	char * service_name );
 
 /**************************************************************************/
 /*	
@@ -373,7 +383,7 @@ int rpg_serveropen (int type ,	char * service_name );
 	ΥץȥѤʤ³׵դ
 	СåȤ򥪡ץ󤹤
 
-	δؿȤäƥСץ󤹤ȡrpg_poll³׵ϼưǼ
+	δؿȤäƥСץ󤹤ȡLP_Poll³׵ϼưǼ
 		#define LIBNETCONNECTREQUESTRAWT    10012       TCP RAWSERVER ³׵
 		#define LIBNETCONNECTREQUESTRAWU    10011       UNIX SOC RAWSERVER³׵
 		֤
@@ -384,13 +394,13 @@ int rpg_serveropen (int type ,	char * service_name );
 
 		ʬǼȤˤϥСץǹԤ
 		ΣƣĤңףϿ򤷤ƻѤ
-			int rpg_addRawPollFD(int FD)Ѥ롣
-	ʾ	rpg_poll()
+			int LP_addRawPollFD(int FD)Ѥ롣
+	ʾ	LP_Poll()
 
  
  */
 
-int rpg_RawServerOpen(int type ,    char * service_name );
+int LP_RawServerOpen(int type ,    char * service_name );
 
 
 /**************************************************************************/
@@ -409,10 +419,12 @@ int rpg_RawServerOpen(int type ,    char * service_name );
 
 */
 
-int rpg_tcp_client_open( char * hostname , char * service_name );
-int rpg_udp_client_open( char * hostname , char * service_name );
-int rpg_tcp_client_open_port( char * hostname , int port );
-int rpg_udp_client_open_port( char * hostname , int port );
+int LP_tcp_client_open( char * hostname , char * service_name );
+int LP_tcp_raw_client_open( char * hostname , char * service_name );
+int LP_udp_client_open( char * hostname , char * service_name );
+int LP_tcp_client_open_port( char * hostname , int port );
+int LP_tcp_raw_client_open_port( char * hostname , int port );
+int LP_udp_client_open_port( char * hostname , int port );
 
 
 /**************************************************************************/
@@ -428,7 +440,7 @@ int rpg_udp_client_open_port( char * hostname , int port );
 
 */
 
-int rpg_usoc_client_open(char * socketname);
+int LP_usoc_client_open(char * socketname);
 
 
 /**************************************************************************/
@@ -446,8 +458,8 @@ int rpg_usoc_client_open(char * socketname);
 	͡
 
 */
-int rpg_send(int FD ,char * command ,  char * senddata , int len);
-int rpg_send_udp(int FD ,char * command ,  char * senddata , int len);
+int LP_send(int FD ,char * command ,  char * senddata , int len);
+int LP_send_udp(int FD ,char * command ,  char * senddata , int len);
 
 
 /**************************************************************************/
@@ -462,7 +474,7 @@ int rpg_send_udp(int FD ,char * command ,  char * senddata , int len);
 		struct  timeval timeout		I	ॢȻ
 */
 
-int rpg_eventloop( char * data , int * leng	 , struct  timeval timeout );
+int LP_eventloop( char * data , int * leng	 , struct  timeval timeout );
 
 
 
@@ -533,7 +545,7 @@ int rpg_eventloop( char * data , int * leng	 , struct  timeval timeout );
 	͡
 
 */
-int RPG_Poll( char * command , char * data , int buf_length , int *length , int	 timeout  , int *fd);
+int LP_Poll( char * command , char * data , int buf_length , int *length , int	 timeout  , int *fd);
 
 
 
@@ -551,50 +563,50 @@ int RPG_Poll( char * command , char * data , int buf_length , int *length , int
 ͤƤǤ礦
 
 int loginit( char * pname );
-int rpg_dbglvl(int dbglvl);
-int rpglog(int DBlev , char * errbuf , ...);
-int rpg_gamelog();
+int LP_dbglvl(int dbglvl);
+int LP_log(int DBlev , char * errbuf , ...);
+int LP_gamelog();
 
 ФΤߤȤΤ
-char *  rpg_setlogfile(char * filename);
+char *  LP_setlogfile(char * filename);
 եΥѥϤ̾ܣУɣĤե̾Ȥʤ
-int rpg_gamelog( int dbglvl ,char * msg );
+int LP_gamelog( int dbglvl ,char * msg );
 줿ǥХå٥ȥ٤ƤȤƤ錄
-int rpg_dbglvl(int dbglvl);
+int LP_dbglvl(int dbglvl);
 ˤäƥ󥰥٥򥻥åȤ롣
 
 
 
 饤ȤϤޤ
 
-int rpg_loginit( char * pname , char * sockname );
+int LP_loginit( char * pname , char * sockname );
 
 ˤơФ³򤹤
-int rpg_dbglvl(int dbglvl);
+int LP_dbglvl(int dbglvl);
 饤Ȥξ³˼ԤΤǥե˽񤭹ޤʤ
 СФ³ԤȤϥǥХå٥˱ɸ२顼ޤɸϤ˽Ф
 Τȡ
 
-int rpglog(int DBlev , char * errbuf , ...);
+int LP_log(int DBlev , char * errbuf , ...);
 
 ˤƥϤ
 ⤷եˤȤ䡢ɸϤ˽Ф
 
-int rpg_dbglvl(int dbglvl);
+int LP_dbglvl(int dbglvl);
 
 ȤοˤɸϤˤɽ
 Ф³Ԥƥե˽񤭽ФȤ
 ǥХå٥ʲΤΤ񤭹ޤ롢
 ΤǥХå٥夲Ⱦܺ٤ˤʤꡢȽפʤΤ
 񤫤ʤʤ롣
-       #define RPGEMERGLEVEL    10   system is unusable
-       #define RPGALERTLEVEL    20   action must be taken immediately
-       #define RPGCRITLEVEL     30   critical conditions
-       #define RPGERRLEVEL      40   error conditions
-       #define RPGWARNINGLEVEL  50   warning conditions
-       #define RPGNOTICELEVEL   60   normal but significant condition /
-       #define RPGINFOLEVEL     70   informational                  /
-       #define RPGDEBUGLEVEL    20   debug-level messages               /
+       #define LIBNET_DBG_EMERG    10   system is unusable
+       #define LIBNET_DBG_ALERT    20   action must be taken immediately
+       #define LIBNET_DBG_CRIT     30   critical conditions
+       #define LIBNET_DBG_ERR      40   error conditions
+       #define LIBNET_DBG_WARNING  50   warning conditions
+       #define LIBNET_DBG_NOTICE   60   normal but significant condition /
+       #define LIBNET_DBG_INFO     70   informational                  /
+       #define LIBNET_DBG_DEBUG    20   debug-level messages               /
 ΥǥեȤռФ褦ˤ
 饤֥ϤΥ٥˱äƥ󥰤褦˥ǥ󥰤롣
 
@@ -620,7 +632,7 @@ int rpg_dbglvl(int dbglvl);
 
 
 */
-char *  rpg_setlogfile(char * filename);
+char *  LP_setlogfile(char * filename);
 /**************************************************************************/
 /*			ν
 	
@@ -635,16 +647,16 @@ char *  rpg_setlogfile(char * filename);
 
 
 */
-int rpglog(int level , char * buf , ... );
+int LP_log(int level , char * buf , ... );
 
-	   #define RPGEMERGLEVEL	10	/* system is unusable				*/
-	   #define RPGALERTLEVEL	20	/* action must be taken immediately */
-	   #define RPGCRITLEVEL		30	/* critical conditions				*/
-	   #define RPGERRLEVEL		40	/* error conditions					*/
-	   #define RPGWARNINGLEVEL	50	/* warning conditions				*/
-	   #define RPGNOTICELEVEL	60	/* normal but significant condition */
-	   #define RPGINFOLEVEL		70	/* informational					*/
-	   #define RPGDEBUGLEVEL	80	/* debug-level messages				*/
+	   #define LIBNET_DBG_EMERG	10	/* system is unusable				*/
+	   #define LIBNET_DBG_ALERT	20	/* action must be taken immediately */
+	   #define LIBNET_DBG_CRIT		30	/* critical conditions				*/
+	   #define LIBNET_DBG_ERR		40	/* error conditions					*/
+	   #define LIBNET_DBG_WARNING	50	/* warning conditions				*/
+	   #define LIBNET_DBG_NOTICEL	60	/* normal but significant condition */
+	   #define LIBNET_DBG_INFO		70	/* informational					*/
+	   #define LIBNET_DBG_DEBUG	80	/* debug-level messages				*/
 	
 
 
@@ -663,7 +675,7 @@ int rpglog(int level , char * buf , ... );
 	͡
 
 */
-int rpg_loginit( char * pname , char * sockname );
+int LP_loginit( char * pname , char * sockname );
 int loginit( char * pname ); /*ϸŤ⤦Ȥʤ*/
 
 
@@ -676,12 +688,14 @@ int loginit( char * pname ); /*ϸŤ⤦Ȥʤ*/
 		Ĵ
 
 	
-		int dbglvl		I	ǥХå٥
+		int dbglvl		I	ꤹǥХå٥
+							(:0ꤷ硢ǥХå٥ϹԤʤ)
 
 	͡
+		int		ߤΥǥХå٥
 
 */
-int rpg_dbglvl(int dbglvl);
+int LP_dbglvl(int dbglvl);
 
 
 /**************************************************************************/
@@ -702,13 +716,13 @@ int rpg_dbglvl(int dbglvl);
 
 
 */
-int rpg_gamelog(int dbglvl ,char * tmpbuf );
+int LP_gamelog(int dbglvl ,char * tmpbuf );
 
 /* С
  *  * 饤ȤΡRPGLOGREQ򤦤
  *   * ΥǡȤϤ
  *    * ǥХå٥򥻥åȤƥ󥰤*/
-int rpg_receveLogwrite(char * readbuf);
+int LP_receveLogwrite(char * readbuf);
 
 /**********************************************************/
 /**********************************************************
@@ -716,16 +730,16 @@ int rpg_receveLogwrite(char * readbuf);
 
 ͭѤϺ¦ץ¦ץʬޤ
 ¦ϰʲΥץȤ
-	char *  RPG_shmctl_init(shment * shmentry , int entrynom  , int *ctlshmid );
-	char *  RPG_shmctl_addentry(int shmNO  , int size );
-	void PRG_shmctl_destroy();
+	char *  LP_shmctl_init(shment * shmentry , int entrynom  , int *ctlshmid );
+	char *  LP_shmctl_addentry(int shmNO  , int size );
+	void LP_shmctl_destroy();
 
 
 ¦ϰʲΥץȤ
-	RPG_shmunit * RPG_shm_init(int ctlshmid);
-	RPG_shmunit * RPG_shm_all_attach(int ctlshmid );
-	char * RPG_shm_attach(int shmNO);
-	void  RPG_shm_all_detach();
+	LP_shmunit * LP_shm_init(int ctlshmid);
+	LP_shmunit * LP_shm_all_attach(int ctlshmid );
+	char * LP_shm_attach(int shmNO);
+	void  LP_shm_all_detach();
 
 
 ͭ깽¤*/
@@ -734,14 +748,14 @@ int rpg_receveLogwrite(char * readbuf);
 		int size;           /*ͭ礭*/
 		char * adder;       /*ͭꥳȥ¦ݥ*/
 
-	}RPG_shmunit;
+	}LP_shmunit;
 
 /*
 ι¤Τˤ뤳ι¤ΤΥ쥳ֹ椬
-ΤޤޣңУǶֹͭȤʤ롢¦⤳ֹѤ
+Τޤޣ̣жֹͭȤʤ롢¦⤳ֹѤ
 å򤹤롣*/
 
-/*RPG_shmunit * RPG_shm = NULL;*/
+/*LP_shmunit * LP_shm = NULL;*/
 
 /*γѿ饤֥ͭƤ롣
 ι¤ΤΥ쥳ɿ*/
@@ -795,7 +809,7 @@ int rpg_receveLogwrite(char * readbuf);
 		char *  	ȥΰΥݥ
 
 */
-char *  RPG_shmctl_init(shment * shmentry , int entrynom  , int *ctlshmid );
+char *  LP_shmctl_init(shment * shmentry , int entrynom  , int *ctlshmid );
 
 
 /**************************************************************************/
@@ -805,7 +819,7 @@ char *  RPG_shmctl_init(shment * shmentry , int entrynom  , int *ctlshmid );
 		ͭɲôؿ
 		ϿƤ붦ͭ򥨥ȥ꡼ɲä
 
-		ϿRPG_shmctl_initǹԤ夫ɲä
+		ϿLP_shmctl_initǹԤ夫ɲä
 		Ȥ
 
 	
@@ -816,7 +830,7 @@ char *  RPG_shmctl_init(shment * shmentry , int entrynom  , int *ctlshmid );
 		ͭؤΥݥ
 
 */
-char *  RPG_shmctl_addentry(int shmNO  , int size );
+char *  LP_shmctl_addentry(int shmNO  , int size );
 
 
 /**************************************************************************/
@@ -833,7 +847,7 @@ char *  RPG_shmctl_addentry(int shmNO  , int size );
 		ʤ
 
 */
-void PRG_shmctl_destroy(void);
+void LP_shmctl_destroy(void);
 
 
 /**************************************************************************/
@@ -841,9 +855,9 @@ void PRG_shmctl_destroy(void);
 				饤Ѷͭؿ
 	
 			饤Ѥ˶ͭ
-			RPG_shm_attach(int shmNO)
+			LP_shm_attach(int shmNO)
 			Ȥ߹碌ƻȤǽ
-			RPG_shm_init(int ctlshmid)ƤӽФ
+			LP_shm_init(int ctlshmid)ƤӽФ
 			Ƥ顢ңУǶֹͭꤷ
 			
 
@@ -851,11 +865,11 @@ void PRG_shmctl_destroy(void);
 			int ctlshmid		I		ͭꥳȥΰζͭɣ
 
 	͡
-			RPG_shmunit * ͭꥳȥؤΥݥ󥿤֤
+			LP_shmunit * ͭꥳȥؤΥݥ󥿤֤
 
 */
 
-RPG_shmunit * RPG_shm_init(int ctlshmid);
+LP_shmunit * LP_shm_init(int ctlshmid);
 
 
 /**************************************************************************/
@@ -869,10 +883,10 @@ RPG_shmunit * RPG_shm_init(int ctlshmid);
 			int ctlshmid		I		ͭꥳȥΰζͭɣ
 
 	͡
-			RPG_shmunit * ͭꥳȥؤΥݥ󥿤֤
+			LP_shmunit * ͭꥳȥؤΥݥ󥿤֤
 
 */
-RPG_shmunit * RPG_shm_all_attach(int ctlshmid );
+LP_shmunit * LP_shm_all_attach(int ctlshmid );
 /**************************************************************************/
 
 
@@ -881,9 +895,9 @@ RPG_shmunit * RPG_shm_all_attach(int ctlshmid );
 		饤Ѷͭꥢåؿ
 	
 			饤Ѥ˶ͭ򥢥å
-			RPG_shm_init(int ctlshmid)
+			LP_shm_init(int ctlshmid)
 			Ȥ߹碌ƻȤǽ
-			RPG_shm_init(int ctlshmid)ƤӽФ
+			LP_shm_init(int ctlshmid)ƤӽФ
 			Ƥ顢ңУǶֹͭꤷ
 			
 
@@ -894,7 +908,7 @@ RPG_shmunit * RPG_shm_all_attach(int ctlshmid );
 			åͭؤΥݥ
 
 */
-char * RPG_shm_attach(int shmNO);
+char * LP_shm_attach(int shmNO);
 
 
 /**************************************************************************/
@@ -902,7 +916,7 @@ char * RPG_shm_attach(int shmNO);
 				ͭǥåؿ
 
 	
-		ͭΤǥå򤹤
+		ͭΥǥå򤹤
 		ͭǥåؿ
 		åͭΰ򤹤٤Ƥǥå
 		ʬΥץΤͭ¾Υץ˱ƶ
@@ -915,7 +929,7 @@ char * RPG_shm_attach(int shmNO);
 		ʤ
 
 */
-void  RPG_shm_detach(void);
+void  LP_shm_detach(void);
 
 /**************************************************************************/
 /*	
@@ -933,18 +947,18 @@ void  RPG_shm_detach(void);
 		ʤ
 
 */
-void  RPG_shm_all_detach(void);
+void  LP_shm_all_detach(void);
 
 /**************************************************************************/
 /*	
 		ͭ
 
-	char * rpg_mopen(char * filepath );
+	char * LP_mopen(char * filepath );
 	ǥץ򤷤
-	void rpg_msync(char * filepath);
+	void LP_msync(char * filepath);
 	ǥեȿǤ
-	void rpg_mallclose();
-	void rpg_mclose(char * filepath);
+	void LP_mallclose();
+	void LP_mclose(char * filepath);
 	ǥ
 
 */
@@ -973,7 +987,7 @@ typedef struct{
 		̵
 
 */
-void rpg_msync(char * filepath);
+void LP_msync(char * filepath);
 /**************************************************************************/
 /*	
 			ޥåפ줿
@@ -987,7 +1001,7 @@ void rpg_msync(char * filepath);
 		̵
 
 */
-void rpg_mallclose();
+void LP_mallclose();
 /**************************************************************************/
 /*		
 			ޥåפ줿Υ
@@ -1002,7 +1016,7 @@ void rpg_mallclose();
 	͡
 		̵
 */
-void rpg_mclose(char * filepath);
+void LP_mclose(char * filepath);
 /**************************************************************************/
 /*	
 			ե˥ޥåפ
@@ -1019,7 +1033,7 @@ void rpg_mclose(char * filepath);
 		char * 			Ÿ줿꡼ؤΥݥ
 
 */
-char * rpg_mopen(char * filepath );
+char * LP_mopen(char * filepath );
 /**************************************************************************/
 
 
@@ -1070,7 +1084,7 @@ char * rpg_mopen(char * filepath );
 	͡
 
 */
-int rpg_seclevel( int level1);
+int LP_seclevel( int level1);
 /**************************************************************************/
 
 
@@ -1084,7 +1098,7 @@ int rpg_seclevel( int level1);
 	͡
 
 */
-int rpg_secdisksp(int alarm_size);
+int LP_secdisksp(int alarm_size);
 
 
 /**************************************************************************/
@@ -1098,7 +1112,7 @@ int rpg_secdisksp(int alarm_size);
 
 
 */
-int rpg_secmailtoadmin(void);
+int LP_secmailtoadmin(void);
 
 
 /**************************************************************************/
@@ -1113,7 +1127,7 @@ int rpg_secmailtoadmin(void);
 
 		
 */
-int rpg_secbeepmachine(void);
+int LP_secbeepmachine(void);
 
 
 /**************************************************************************/
@@ -1125,7 +1139,7 @@ int rpg_secbeepmachine(void);
 	͡
 
 */
-int rpg_secallwerninng(void);
+int LP_secallwerninng(void);
 
 
 /**************************************************************************/
@@ -1137,7 +1151,7 @@ int rpg_secallwerninng(void);
 	͡
 
 */
-int rpg_secall_shutdown(void);
+int LP_secall_shutdown(void);
 
 
 /**************************************************************************/
@@ -1149,7 +1163,7 @@ int rpg_secall_shutdown(void);
 	͡
 
 */
-int rpg_savedata(void);
+int LP_savedata(void);
 
 
 /**************************************************************************/
@@ -1161,7 +1175,7 @@ int rpg_savedata(void);
 	͡
 
 */
-int rpg_gethash ( unsigned short * data , int len);
+int LP_gethash ( unsigned short * data , int len);
 
 
 /**************************************************************************/
@@ -1182,7 +1196,7 @@ int rpg_gethash ( unsigned short * data , int len);
 		char *	顼åΥȥ֤
 
 */
-char *rpg_net_perror(int l_errno ,char ** message);
+char *LP_net_perror(int l_errno ,char ** message);
 /**************************************************************************/
 
 /****************************************************************************/
