@@ -69,7 +69,7 @@ int shmtest(char *command , char * readbuf , int read_len , int resfd);
 #define DEFAULTGAMENAME "laureltest"
 #define CONFIGFILENAME "config_file.csv"
 #define LAURELLOGFILENAME  "laurelsampcli.log"
-#define LOGFUNCLEVEL        150
+#define LIBNET_DBG_LOGFUNC        150
 #define STDIN				0
 
     int UNIXserverFD;
@@ -77,7 +77,7 @@ int shmtest(char *command , char * readbuf , int read_len , int resfd);
     int UDPserverFD;
 	
 	static  int ctlshmid; /*ͭѣɣĥåΰ*/
-	RPG_shmunit * ctlshmadder;
+	LP_shmunit * ctlshmadder;
 	char * shmadder;
 	char *adder;
 	int testflag=0;
@@ -124,9 +124,9 @@ EVTBL eventkye[20] = {
 	{HELTHCHKOK,             helthcheck},     /*إ륹å*/
 	{DBGLEVEL,               chdlevel},       /*ǥХå٥ѹ׵*/
 	{ENDREQ,                 endreq},         /*λ׵*/
-	{POLLTIMEUP,			 OnTimeup},
+	{LIBNET_CMD_POLLTIMEUP,			 OnTimeup},
 	{SHMCTLREQ,              shmctlreq},         /*ͭꥳȥΰ*/
-	{LIBNETRAWDATARECEVE,	 rawdatarec},	/*rawμؤ*/
+	{LIBNET_CMD_RAWDATARECEVE,	 rawdatarec},	/*rawμؤ*/
 	{MMAPTESTREQ,           mmaptest},
 	{SHMEMTESTREQ,          shmtest},
 	{"",                     NULL}
@@ -193,13 +193,13 @@ int set_opt(int argc, char *argv[]){
                 exit (1);
              break;
            case 'f':
-                rpg_setlogfile(optarg);
+                LP_setlogfile(optarg);
              break;
            case 's':
                 logsockname(optarg);
              break;
            case 'd':
-                rpg_dbglvl(atoi(optarg));
+                LP_dbglvl(atoi(optarg));
              break;
            case 'g':
                 gamename(optarg);
@@ -234,8 +234,8 @@ int main (int argc, char *argv[])
 	FILE *fp;
 
     /*ǥեͤ򥻥åȤ*/
-    rpg_dbglvl(101);
-    rpg_setlogfile(LAURELLOGFILENAME);
+    LP_dbglvl(101);
+    LP_setlogfile(LAURELLOGFILENAME);
 
     /*ᤷѿ˼Ǽ*/
     set_opt(argc,argv);
@@ -243,7 +243,7 @@ int main (int argc, char *argv[])
     /*ե졼եɤ߹*/
 
     /*եΥץ*/
-    if ((ret=  rpglog(RPGEMERGLEVEL ,"start loging\n" )) < 0){
+    if ((ret=  LP_log(LIBNET_DBG_EMERG ,"start loging\n" )) < 0){
         printf("logopnen error abort\n");
         exit (0);
     }
@@ -269,42 +269,42 @@ int main (int argc, char *argv[])
 /*TODO ץ
  * ˥ååȡ̾դѥסˤΥ饤ȥץ*/
     /*ͥåȥΥץ(˥ååȤΥ饤ȥץ)*/
-    UNIXserverFD = rpg_usoc_client_open(testval.UnixSocName );
+    UNIXserverFD = LP_usoc_client_open(testval.UnixSocName );
     if (UNIXserverFD <= 0){
-        rpglog(RPGEMERGLEVEL,"rpg_usoc_client_open error [%s] [%s] [%d]\n",testval.UnixSocName, strerror(errno) , ret);
-        rpg_endproc(1);
+        LP_log(LIBNET_DBG_EMERG,"LP_usoc_client_open error [%s] [%s] [%d]\n",testval.UnixSocName, strerror(errno) , ret);
+        LP_endproc(1);
     }
 	
 /*TODO ץ
  * ԣãХåȤΥ饤ȥץ*/
-    TCPserverFD = rpg_tcp_client_open(testval.hostname,testval.portnom );
+    TCPserverFD = LP_tcp_client_open(testval.hostname,testval.portnom );
     if (TCPserverFD <= 0){
-        rpglog(RPGEMERGLEVEL,"rpg_tcp_client_open error [%s] [%s] [%d]\n",testval.portnom, strerror(errno) , ret);
-        rpg_endproc(1);
+        LP_log(LIBNET_DBG_EMERG,"LP_tcp_client_open error [%s] [%s] [%d]\n",testval.portnom, strerror(errno) , ret);
+        LP_endproc(1);
     }
 /*TODO ץ
  * UDPåȤΥ饤ȥץ*/
-    rpglog(RPGEMERGLEVEL,"rpg_udp_client_open [%s] [%s]\n",testval.Uportnom, strerror(errno) );
-    UDPserverFD = rpg_udp_client_open(testval.hostname,testval.Uportnom );
+    LP_log(LIBNET_DBG_EMERG,"LP_udp_client_open [%s] [%s]\n",testval.Uportnom, strerror(errno) );
+    UDPserverFD = LP_udp_client_open(testval.hostname,testval.Uportnom );
     if (UDPserverFD <= 0){
-        rpglog(RPGEMERGLEVEL,"rpg_udp_client_open error [%s] [%s] [%d]\n",testval.Uportnom, strerror(errno) , ret);
-        rpg_endproc(1);
+        LP_log(LIBNET_DBG_EMERG,"LP_udp_client_open error [%s] [%s] [%d]\n",testval.Uportnom, strerror(errno) , ret);
+        LP_endproc(1);
     }
     /*ͭγ*/
 /*TODO ץ
  * ͣͣͭΥץ*/
-    (char *)ret = rpg_mopen(testval.MMapFilePath);
+    (char *)ret = LP_mopen(testval.MMapFilePath);
     if ((char *)ret == NULL){
-        rpglog (RPGEMERGLEVEL,"cant open mmmap\n");
-        rpg_endproc(RPG_NG);
+        LP_log (LIBNET_DBG_EMERG,"cant open mmmap\n");
+        LP_endproc(LP_NG);
     }
     adder = (char *)ret;
 
 /*TODO ץ*/
     /*ФȤΥå³*/
-    ret = rpg_loginit( argv[0] , LAURELLOGSOCNAME);
+    ret = LP_loginit( argv[0] , LAURELLOGSOCNAME);
     if (ret < 0){
-        rpglog (RPGEMERGLEVEL,"cant connect log server\n");
+        LP_log (LIBNET_DBG_EMERG,"cant connect log server\n");
     }
 
 
@@ -314,26 +314,26 @@ int main (int argc, char *argv[])
 		ret = fork();
 		if (ret > 0){
 			if (ret==1){
-				rpglog (RPGEMERGLEVEL,"cant fork child prosses\n");
+				LP_log (LIBNET_DBG_EMERG,"cant fork child prosses\n");
 			}
 			exit (1);
 		}
 /* ȤɸϤңףƣϿư򸡾ڤ*/
 	}else{
-		rpglog (RPGEMERGLEVEL,"set Raw FD\n");
+		LP_log (LIBNET_DBG_EMERG,"set Raw FD\n");
 
-		rpg_addRawPollFD(STDIN);
+		LP_addRawPollFD(STDIN);
 
 	}
 	/*ͭɣĤ򥵡Ф˥䤤碌ʶͭȤɬܡ*/
-	rpg_send(TCPserverFD,SHMCTLREQ,"",0);
+	LP_send(TCPserverFD,SHMCTLREQ,"",0);
 
     /*ᥤ롼*/
     while (1){
         memset (readbuf , 0 , 1024);
-        ret = RPG_Poll (command ,  readbuf , 1024, &read_len , 10000 , &resfd );
+        ret = LP_Poll (command ,  readbuf , 1024, &read_len , 10000 , &resfd );
         readbuf[1023]=0;
-        rpglog(1050, "ret %d [%.10s] \n" , ret , command );
+        LP_log(1050, "ret %d [%.10s] \n" , ret , command );
         for (cnt=0;cnt<20;cnt++){
             if (eventkye[cnt].func==NULL)break;
                 /*ޥʸӤפ*/
@@ -343,97 +343,97 @@ int main (int argc, char *argv[])
             }
         }
     }
-    return RPG_OK;
+    return LP_OK;
 }
 
 /*ߡؿ*/
 int dummyfunc(char *command , char * readbuf , int read_len , int resfd){
-    rpglog(LOGFUNCLEVEL , "dummyfunc\n");
+    LP_log(LIBNET_DBG_LOGFUNC , "dummyfunc\n");
 
-    return RPG_OK;
+    return LP_OK;
 }
 /*إ륹åؿ׵ξ*/
 int helthcheck(char *command , char * readbuf , int read_len , int resfd){
-    rpglog(LOGFUNCLEVEL , "helthcheck\n");
+    LP_log(LIBNET_DBG_LOGFUNC , "helthcheck\n");
 
     /*ֿ*/
     if (memcmp(HELTHCHK,command,COMMANDLEN)==0){
-        rpg_send(resfd,HELTHCHKOK,"",0);
+        LP_send(resfd,HELTHCHKOK,"",0);
     }else{
-		rpg_send(UNIXserverFD,DYMMYMES , "",0);
+		LP_send(UNIXserverFD,DYMMYMES , "",0);
 	}
-    return RPG_OK;
+    return LP_OK;
 }
 /*ǥХå٥ѹ׵*/
 int chdlevel(char *command , char * readbuf , int read_len , int resfd){
     int rev;
-    rpglog(LOGFUNCLEVEL , "chdlevel\n");
+    LP_log(LIBNET_DBG_LOGFUNC , "chdlevel\n");
     /*ӥåǥб*/
     rev = ntohl (*((int *)readbuf));
-    rpg_dbglvl(rev);
-    return RPG_OK;
+    LP_dbglvl(rev);
+    return LP_OK;
 }
 /*λ׵*/
 int endreq(char *command , char * readbuf , int read_len , int resfd){
-    rpglog(LOGFUNCLEVEL , "endreq\n");
-    rpg_fd_allclose();
-    rpglog(-1,"end log file\n");
+    LP_log(LIBNET_DBG_LOGFUNC , "endreq\n");
+    LP_fd_allclose();
+    LP_log(-1,"end log file\n");
 	exit(0);
 }
 
 int OnTimeup(char *command , char * readbuf , int read_len , int resfd){
-    rpglog(LOGFUNCLEVEL , "OnTimeup\n");
+    LP_log(LIBNET_DBG_LOGFUNC , "OnTimeup\n");
 
 	/*إ륹å*/
-	/*rpg_send( TCPserverFD, HELTHCHK , "",0);*/
+	/*LP_send( TCPserverFD, HELTHCHK , "",0);*/
 
 }
 
 /*ͭꥳȥɣļؿ*/
 int shmctlreq(char *command , char * readbuf , int read_len , int resfd){
 	memcpy ((char *)&ctlshmid , readbuf , sizeof(int));
-	rpglog(LOGFUNCLEVEL , "shmctlreq %d\n" , ctlshmid);
+	LP_log(LIBNET_DBG_LOGFUNC , "shmctlreq %d\n" , ctlshmid);
 
 	/*ȥɣĤǤ麣٤*/
-	ctlshmadder = RPG_shm_init (ctlshmid);
-	shmadder =  (char *)RPG_shm_attach( testval.shmID);
-	rpglog(LOGFUNCLEVEL , "shmctlreq:shmadder [%x] %d\n",shmadder,shmadder);
+	ctlshmadder = LP_shm_init (ctlshmid);
+	shmadder =  (char *)LP_shm_attach( testval.shmID);
+	LP_log(LIBNET_DBG_LOGFUNC , "shmctlreq:shmadder [%x] %d\n",shmadder,shmadder);
 
-	return RPG_OK;
+	return LP_OK;
 }
 
 /*ɸϤΥޥɼջ*/
 int rawdatarec(char *command , char * readbuf , int read_len , int resfd){
-	rpglog(LOGFUNCLEVEL , "rawdatarec\n");
 	char buf[1024];
 	char sendbuf[4000];
 	int ret,cnt;
 	int sum;
+	LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec\n");
 	/*****************************************************/
 	/*			Ƽƥȥɤ					*/
 	/*****************************************************/
 
 	ret = read (STDIN , buf,1024);
 	if (ret == 0){
-		rpglog(LOGFUNCLEVEL , "rawdatarec:read length 0\n");
-		return RPG_OK;
+		LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:read length 0\n");
+		return LP_OK;
 	}
 
 
 	/*إ륹å*/
 	if (NULL!= strstr(buf,"HELTHCHK")){ 
-		rpg_send( TCPserverFD, HELTHCHK , "",0);
+		LP_send( TCPserverFD, HELTHCHK , "",0);
 		
 	}else if(NULL!= strstr(buf,"SENDTEST")){
 	/*ƥ*/
 		if(NULL!= strstr(buf,"UDP")){
-			rpglog(LOGFUNCLEVEL , "rawdatarec:UDP send test start\n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:UDP send test start\n");
 			/*UDP*/
-			rpglog(LOGFUNCLEVEL , "rawdatarec:UDP normal send \n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:UDP normal send \n");
 			sprintf(sendbuf,"rawdatarec:UDP send test start");
-			rpg_send(UDPserverFD,NORMALSENDTEST ,sendbuf ,strlen(sendbuf));
+			LP_send(UDPserverFD,NORMALSENDTEST ,sendbuf ,strlen(sendbuf));
 			/*礭ʥǡʣХȰʾ*/
-			rpglog(LOGFUNCLEVEL , "rawdatarec:UDP big data send \n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:UDP big data send \n");
 			for(sum=0,cnt=0;cnt<3500;cnt++){
 				int i;
 				i=(int) (10.0*rand()/(RAND_MAX+1.0))+060;
@@ -443,25 +443,25 @@ int rawdatarec(char *command , char * readbuf , int read_len , int resfd){
 				sum=sum+i;
 			}
 			snprintf(&(sendbuf[3500]),500,"%d",sum);
-			rpg_send(UDPserverFD,LARGESENDTEST,sendbuf ,4000);
+			LP_send(UDPserverFD,LARGESENDTEST,sendbuf ,4000);
 			/*ʥǡʣʥѥå礬Ԥ١*/
-			rpglog(LOGFUNCLEVEL , "rawdatarec:UDP small data lot send \n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:UDP small data lot send \n");
 			for(cnt=0;cnt<500;cnt++){
 				sprintf(sendbuf,"%d",cnt);
-				rpg_send(UDPserverFD,SMALLSENDTEST,sendbuf ,strlen(sendbuf));
+				LP_send(UDPserverFD,SMALLSENDTEST,sendbuf ,strlen(sendbuf));
 			}
 
 
 		}else if(NULL!= strstr(buf,"UNIX")){
-			rpglog(LOGFUNCLEVEL , "rawdatarec:UNIX send test start\n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:UNIX send test start\n");
 
 			/*գΣɣإå*/
 			sprintf(sendbuf,"rawdatarec:UNIX send test start");
-			rpg_send(UNIXserverFD,NORMALSENDTEST ,sendbuf ,strlen(sendbuf));
-			rpglog(LOGFUNCLEVEL , "rawdatarec:UNIX normal send \n");
+			LP_send(UNIXserverFD,NORMALSENDTEST ,sendbuf ,strlen(sendbuf));
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:UNIX normal send \n");
 
 			/*礭ʥǡʣХȰʾ*/
-			rpglog(LOGFUNCLEVEL , "rawdatarec:UNIX big data send \n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:UNIX big data send \n");
 			for(sum=0,cnt=0;cnt<3500;cnt++){
 				int i;
 				i=(int) (10.0*rand()/(RAND_MAX+1.0))+060;
@@ -471,22 +471,22 @@ int rawdatarec(char *command , char * readbuf , int read_len , int resfd){
 				sum=sum+i;
 			}
 			snprintf(&(sendbuf[3500]),500,"%d",sum);
-			rpg_send(UNIXserverFD,LARGESENDTEST,sendbuf ,4000);
+			LP_send(UNIXserverFD,LARGESENDTEST,sendbuf ,4000);
 
 			/*ʥǡʣʥѥå礬Ԥ١*/
-			rpglog(LOGFUNCLEVEL , "rawdatarec:UNIX small data lot send \n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:UNIX small data lot send \n");
 			for(cnt=0;cnt<500;cnt++){
 				sprintf(sendbuf,"%d",cnt);
-				rpg_send(UNIXserverFD,SMALLSENDTEST,sendbuf ,strlen(sendbuf));
+				LP_send(UNIXserverFD,SMALLSENDTEST,sendbuf ,strlen(sendbuf));
 			}
 		}else{
-			rpglog(LOGFUNCLEVEL , "rawdatarec:TCP send test start\n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:TCP send test start\n");
 			/*TCP*/
-			rpglog(LOGFUNCLEVEL , "rawdatarec:TCP normal send \n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:TCP normal send \n");
 			sprintf(sendbuf,"rawdatarec:TCP send test start");
-			rpg_send(TCPserverFD,NORMALSENDTEST ,sendbuf ,strlen(sendbuf));
+			LP_send(TCPserverFD,NORMALSENDTEST ,sendbuf ,strlen(sendbuf));
 			/*礭ʥǡʣХȰʾ*/
-			rpglog(LOGFUNCLEVEL , "rawdatarec:TCP big data send \n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:TCP big data send \n");
 			for(sum=0,cnt=0;cnt<3500;cnt++){
 				int i;
 				i=(int) (10.0*rand()/(RAND_MAX+1.0))+060;
@@ -496,58 +496,58 @@ int rawdatarec(char *command , char * readbuf , int read_len , int resfd){
 				sum=sum+i;
 			}
 			snprintf(&(sendbuf[3500]),500,"%d",sum);
-			rpg_send(TCPserverFD,LARGESENDTEST,sendbuf ,4000);
+			LP_send(TCPserverFD,LARGESENDTEST,sendbuf ,4000);
 			/*ʥǡʣʥѥå礬Ԥ١*/
-			rpglog(LOGFUNCLEVEL , "rawdatarec:TCP small data lot send \n");
+			LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec:TCP small data lot send \n");
 			for(cnt=0;cnt<500;cnt++){
 				sprintf(sendbuf,"%d",cnt);
-				rpg_send(TCPserverFD,SMALLSENDTEST,sendbuf ,strlen(sendbuf));
+				LP_send(TCPserverFD,SMALLSENDTEST,sendbuf ,strlen(sendbuf));
 			}
 		}
 		/**/
 		
 	}else if(NULL!= strstr(buf,"MMAPTESTSEND")){
-		rpglog(LOGFUNCLEVEL , "rawdatarec: mmap test\n");
+		LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec: mmap test\n");
 		/**/
 		for (cnt =0;cnt<2048;cnt++){
 			(unsigned char)(adder[cnt])=cnt%256;
 		}
-		rpg_send(TCPserverFD,MMAPTESTREQ,"+",1);
+		LP_send(TCPserverFD,MMAPTESTREQ,"+",1);
 		sleep (1);
 		for (cnt =0;cnt<2048;cnt++){
 			(unsigned char)(adder[cnt])=(2048-cnt)%256;
 		}
-		rpg_send(TCPserverFD,MMAPTESTREQ,"-",1);
+		LP_send(TCPserverFD,MMAPTESTREQ,"-",1);
 		
 	}else if(NULL!= strstr(buf,"MEMTESTSEND")){
 	/*ͭϤƥ*/
-		rpglog(LOGFUNCLEVEL , "rawdatarec: shered memory test\n");
+		LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec: shered memory test\n");
 
 		/*ͭ*/
 		for (cnt =0;cnt< 0x1000000;cnt++){
 			(unsigned char)(shmadder[cnt])=cnt%256;
 		}
-		rpg_send(TCPserverFD,SHMEMTESTREQ,"+",1);
+		LP_send(TCPserverFD,SHMEMTESTREQ,"+",1);
 		sleep (1);
 		for (cnt =0;cnt< 0x1000000;cnt++){
 			(unsigned char)(shmadder[cnt])=(0x1000000-cnt)%256;
 		}
-		rpg_send(TCPserverFD,SHMEMTESTREQ,"-",1);
+		LP_send(TCPserverFD,SHMEMTESTREQ,"-",1);
 		/**/
 		
 	}else if(NULL!= strstr(buf,"MEMTESTSIZE")){
 	/*ͭꥵƥ*/
-		rpglog(LOGFUNCLEVEL , "rawdatarec: shered memory test\n");
+		LP_log(LIBNET_DBG_LOGFUNC , "rawdatarec: shered memory test\n");
 		/*꤮ޤǽ*/
 		for (cnt =0;cnt< 0x1000000;cnt++){
 			(unsigned char)(shmadder[cnt])=cnt%256;
 		}
-		rpg_send(TCPserverFD,SHMEMTESTREQ,"+",1);
+		LP_send(TCPserverFD,SHMEMTESTREQ,"+",1);
 		sleep (1);
 		for (cnt =0;cnt< 0x1000000;cnt++){
 			(unsigned char)(shmadder[cnt])=(0x1000000-cnt)%256;
 		}
-		rpg_send(TCPserverFD,SHMEMTESTREQ,"-",1);
+		LP_send(TCPserverFD,SHMEMTESTREQ,"-",1);
 		/**/
 
 	}else if(NULL!= strstr(buf,"HELP")){
@@ -576,54 +576,54 @@ int rawdatarec(char *command , char * readbuf , int read_len , int resfd){
 	/**/
 	}
 
-	return RPG_OK;
+	return LP_OK;
 }
 
 int mmaptest(char *command , char * readbuf , int read_len , int resfd){
     int cnt;
-    rpglog(100 , "mmaptest: mmapreadtest %s\n",readbuf);
+    LP_log(100 , "mmaptest: mmapreadtest %s\n",readbuf);
 
     if (memcmp(readbuf,"+",1)==0){
         for (cnt =0;cnt<2048;cnt++){
             if ((unsigned char)(adder[cnt])!=cnt%256){
-                rpglog(70 , "mmaptest: error mem mispmatch + [%d]-[%d] [%d]\n",adder[cnt],cnt%256,cnt);
+                LP_log(70 , "mmaptest: error mem mispmatch + [%d]-[%d] [%d]\n",adder[cnt],cnt%256,cnt);
             }
         }
     }else{
         for (cnt =0;cnt<2048;cnt++){
             if ((unsigned char)(adder[cnt])!=(2048-cnt)%256){
-                rpglog(70 , "mmaptest: error mem mispmatch - [%d]-[%d] [%d]\n",adder[cnt],(2048-cnt)%256,cnt);
+                LP_log(70 , "mmaptest: error mem mispmatch - [%d]-[%d] [%d]\n",adder[cnt],(2048-cnt)%256,cnt);
             }
         }
         for (cnt =0;cnt<2048;cnt++){
             (unsigned char)(adder[cnt])=cnt%256;
         }
-        rpg_send(resfd,MMAPTESTREQ,"+",1);
+        LP_send(resfd,MMAPTESTREQ,"+",1);
     }
 
-	return RPG_OK;
+	return LP_OK;
 }
 int shmtest(char *command , char * readbuf , int read_len , int resfd){
     int cnt;
-    rpglog(100 , "shmtest: shmreadtest %s\n",readbuf);
+    LP_log(100 , "shmtest: shmreadtest %s\n",readbuf);
 
     if (readbuf[0]=='+'){
         for (cnt =0;cnt<0x1000000;cnt++){
             if ((unsigned char)(shmadder[cnt])!=cnt%256){
-                rpglog(70 , "shmtest: error mem mispmatch + [%d]-[%d] [%d]\n",shmadder[cnt],cnt%256,cnt);
+                LP_log(70 , "shmtest: error mem mispmatch + [%d]-[%d] [%d]\n",shmadder[cnt],cnt%256,cnt);
             }
         }
     }else{
         for (cnt =0;cnt<0x1000000;cnt++){
             if ((unsigned char)(shmadder[cnt])!=(0x1000000-cnt)%256){
-                rpglog(70 , "shmtest: error mem mispmatch - [%d]-[%d] [%d]\n",shmadder[cnt],(2048-cnt)%256,cnt);
+                LP_log(70 , "shmtest: error mem mispmatch - [%d]-[%d] [%d]\n",shmadder[cnt],(2048-cnt)%256,cnt);
             }
         }
         for (cnt =0;cnt< 0x1000000;cnt++){
             (unsigned char)(shmadder[cnt])=cnt%256;
         }
-        rpg_send(resfd,SHMEMTESTREQ,"+",1);
+        LP_send(resfd,SHMEMTESTREQ,"+",1);
     }
-	return RPG_OK;
+	return LP_OK;
 }
 
