@@ -2,7 +2,7 @@
     <ClientSample.c>>
 ңУǺץ
      ꥨ ͥåȥңУǥ <ͥåȥط饤֥ꥵץ륽>
-	 $Id: LogServerSample.c,v 1.10 2004/01/06 09:49:10 naohki Exp $
+	 $Id: LogServerSample.c,v 1.11 2004/01/24 14:42:27 yamakawa Exp $
      ------------------------------------------------------------
      Copyright (C) 2002ǯ naoki kuwamori<naoki@kuwamori.com>
 
@@ -16,7 +16,7 @@
 
 
     Laurier Net work RPG server<game network library>
-	 $Id: LogServerSample.c,v 1.10 2004/01/06 09:49:10 naohki Exp $
+	 $Id: LogServerSample.c,v 1.11 2004/01/24 14:42:27 yamakawa Exp $
     Copyright (C) 2002 Naoki Kuwamori <naoki@kuwamori.com>
 
     This program is free software; you can redistribute it and/or modify
@@ -55,7 +55,7 @@
  #define DEFAULTGAMENAME "laureltest"
  #define CONFIGFILENAME "config_file.csv"
  #define LAURELLOGFILENAME  "laurelLogserv.log"
- #define LOGFUNCLEVEL        150
+ #define LIBNET_DBG_LOGFUNC        150
 static int dlevel;
 
 /*TODO ץ
@@ -149,7 +149,7 @@ int set_opt(int argc, char *argv[]){
         switch (c)
         {
            case 'v':
-                printf ("LaurelRPG server $Id: LogServerSample.c,v 1.10 2004/01/06 09:49:10 naohki Exp $\n");
+                printf ("LaurelRPG server $Id: LogServerSample.c,v 1.11 2004/01/24 14:42:27 yamakawa Exp $\n");
                 exit (1);
              break;
            case 'h':
@@ -157,7 +157,7 @@ int set_opt(int argc, char *argv[]){
                 exit (1);
              break;
            case 'f':
-                rpg_setlogfile(optarg);
+                LP_setlogfile(optarg);
              break;
            case 's':
                 logsockname(optarg);
@@ -166,7 +166,7 @@ int set_opt(int argc, char *argv[]){
                 dlevel=atoi(optarg);
              break;
            case 'd':
-                rpg_dbglvl(atoi(optarg));
+                LP_dbglvl(atoi(optarg));
              break;
            case 'g':
                 gamename(optarg);
@@ -203,8 +203,8 @@ int main (int argc, char *argv[])
 	FILE * fp;
 
     /*ǥեͤ򥻥åȤ*/
-    rpg_dbglvl(101);
-    rpg_setlogfile(LAURELLOGFILENAME);
+    LP_dbglvl(101);
+    LP_setlogfile(LAURELLOGFILENAME);
 
     /*ᤷѿ˼Ǽ*/
     set_opt(argc,argv);
@@ -212,7 +212,7 @@ int main (int argc, char *argv[])
     /*ե졼եɤ߹*/
 
     /*եΥץ*/
-    if ((ret=  rpg_gamelog(RPGEMERGLEVEL ,"start loging\n" )) < 0){
+    if ((ret=  LP_gamelog(LIBNET_DBG_EMERG ,"start loging\n" )) < 0){
         printf("logopnen error abort\n");
         exit (0);
     }
@@ -236,11 +236,11 @@ int main (int argc, char *argv[])
 /*TODO ץ
  *  * ˥ååȡ̾դѥסˤΥХץ*/
     /*ͥåȥСΥץ(˥ååȤΥץ)*/
-    if ((ret = rpg_serveropen( AF_UNIX ,LAURELLOGSOCNAME)) < 0){
+    if ((ret = LP_serveropen( AF_UNIX ,LAURELLOGSOCNAME)) < 0){
         char errbuf[1024];
-        sprintf (errbuf , "rpg_serveropen error [%s] [%s] [%d]\n",testval.UnixSocName, strerror(errno) , ret);
-        rpg_gamelog (RPGEMERGLEVEL,errbuf);
-        rpg_endproc(RPG_NG);
+        sprintf (errbuf , "LP_serveropen error [%s] [%s] [%d]\n",testval.UnixSocName, strerror(errno) , ret);
+        LP_gamelog (LIBNET_DBG_EMERG,errbuf);
+        LP_endproc(LP_NG);
     }
     UNIXserverFD=ret;
 
@@ -249,7 +249,7 @@ int main (int argc, char *argv[])
     ret = fork();
     if (ret > 0){
         if (ret==1){
-            rpg_gamelog (RPGEMERGLEVEL,"cant fork child prosses\n");
+            LP_gamelog (LIBNET_DBG_EMERG,"cant fork child prosses\n");
         }
         exit (1);
     }
@@ -257,7 +257,7 @@ int main (int argc, char *argv[])
     /*ᥤ롼*/
     while (1){
         memset (readbuf , 0 , 1024);
-        ret = RPG_Poll (command ,  readbuf , 1024, &read_len , 10000 , &resfd );
+        ret = LP_Poll (command ,  readbuf , 1024, &read_len , 10000 , &resfd );
         readbuf[1023]=0;
         for (cnt=0;cnt<20;cnt++){
             if (eventkye[cnt].func==NULL)break;
@@ -268,7 +268,7 @@ int main (int argc, char *argv[])
             }
         }
     }
-    return RPG_OK;
+    return LP_OK;
 }
 
 /*ߡؿ*/
@@ -277,40 +277,40 @@ int logrequest(char *command , char * readbuf , int read_len , int resfd){
 
 	dbglev=ntohl(*((int *)readbuf));
 	if (dbglev < dlevel){
-		return rpg_gamelog(1, &(readbuf[sizeof(int)]));
+		return LP_gamelog(1, &(readbuf[sizeof(int)]));
 	}
-	return RPG_OK;
+	return LP_OK;
 }
 /*ߡؿ*/
 int dummyfunc(char *command , char * readbuf , int read_len , int resfd){
-    rpg_gamelog(LOGFUNCLEVEL , "dummyfunc\n");
+    LP_gamelog(LIBNET_DBG_LOGFUNC , "dummyfunc\n");
 
-    return RPG_OK;
+    return LP_OK;
 }
 /*إ륹åؿ׵ξ*/
 int helthcheck(char *command , char * readbuf , int read_len , int resfd){
-    rpg_gamelog(LOGFUNCLEVEL , "helthcheck\n");
+    LP_gamelog(LIBNET_DBG_LOGFUNC , "helthcheck\n");
 
     /*ֿ*/
     if (memcmp(HELTHCHK,command,COMMANDLEN)==0){
-        rpg_send(resfd,HELTHCHKOK,"",0);
+        LP_send(resfd,HELTHCHKOK,"",0);
     }
-    return RPG_OK;
+    return LP_OK;
 }
 /*ǥХå٥ѹ׵*/
 int chdlevel(char *command , char * readbuf , int read_len , int resfd){
     int rev;
-    rpg_gamelog(LOGFUNCLEVEL , "chdlevel\n");
+    LP_gamelog(LIBNET_DBG_LOGFUNC , "chdlevel\n");
     /*ӥåǥб*/
     rev = ntohl (*((int *)readbuf));
-    rpg_dbglvl(rev);
-    return RPG_OK;
+    LP_dbglvl(rev);
+    return LP_OK;
 }
 /*λ׵*/
 int endreq(char *command , char * readbuf , int read_len , int resfd){
-    rpg_gamelog(LOGFUNCLEVEL , "endreq\n");
-    rpg_fd_allclose();
-    rpg_gamelog(-1,"end log file\n");
+    LP_gamelog(LIBNET_DBG_LOGFUNC , "endreq\n");
+    LP_fd_allclose();
+    LP_gamelog(-1,"end log file\n");
 	exit(0);
 }
 
